LCWAEvaluationLoop
==================

.. currentmodule:: pykeen.evaluation

.. autoclass:: LCWAEvaluationLoop
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~LCWAEvaluationLoop.get_collator
      ~LCWAEvaluationLoop.process_batch

   .. rubric:: Methods Documentation

   .. automethod:: get_collator
   .. automethod:: process_batch
